import { number, object, string } from "yup";

export type CreateAnimal = {
    name: string,
    description: string,
    age: number,
    type: string,
    picture: string
}

export const createAnimalScheme = object({
    name: string()
        .required("Property [name] is missing"),
    description: string()
        .required("Property [description] is missing"),
    age: number()
        .positive("Property [age] should be positive")
        .required("Property [age] is missing"),
    picture: string()
        .required("Property [picture] is missing"),
    type: string()
        .oneOf(["DOG", "CAT"], "Property [type] must be DOG or CAT")
        .required("Property [type] is missing"),
  });


export type UpdateAnimal = Partial<Omit<CreateAnimal, 'id'>>;

export const updateAnimalScheme = object({
    name: string()
        .optional(),
    description: string()
        .optional(),
    age: number()
        .optional(),
    picture: string()
        .optional(),
    type: string()
        .oneOf(["DOG", "CAT"], "Property [type] must be DOG or CAT")
        .optional(),
  });